@@ -1102,10 +1102,11 @@ on_begin_loading (GeditFileBrowserStore  *model,
 		  GtkTreeIter            *iter,
 		  GeditFileBrowserWidget *obj)
 {
-	if (!GDK_IS_WINDOW (GTK_WIDGET (obj->priv->treeview)->window))
+	if (!GDK_IS_WINDOW (gtk_widget_get_window (GTK_WIDGET (obj->priv->treeview))))
 		return;
 
-	gdk_window_set_cursor (GTK_WIDGET (obj)->window, obj->priv->busy_cursor);
+	gdk_window_set_cursor (gtk_widget_get_window (GTK_WIDGET (obj)),
+			       obj->priv->busy_cursor);
 }
 
 static void
@@ -1113,10 +1114,10 @@ on_end_loading (GeditFileBrowserStore  *model,
 		GtkTreeIter            *iter,
 		GeditFileBrowserWidget *obj)
 {
-	if (!GDK_IS_WINDOW (GTK_WIDGET (obj->priv->treeview)->window))
+	if (!GDK_IS_WINDOW (gtk_widget_get_window (GTK_WIDGET (obj->priv->treeview))))
 		return;
 
-	gdk_window_set_cursor (GTK_WIDGET (obj)->window, NULL);
+	gdk_window_set_cursor (gtk_widget_get_window (GTK_WIDGET (obj)), NULL);
 }
 
 static void
@@ -1312,6 +1313,22 @@ popup_menu (GeditFileBrowserWidget * obj, GdkEventButton * event, GtkTreeModel *
 	g_return_val_if_fail (menu != NULL, FALSE);
 
 	if (event != NULL) {
+		GtkTreeSelection *selection;
+		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (obj->priv->treeview));
+
+		if (gtk_tree_selection_count_selected_rows (selection) <= 1) {
+			GtkTreePath *path;
+
+			if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (obj->priv->treeview),
+			                                   (gint)event->x, (gint)event->y,
+			                                   &path, NULL, NULL, NULL))
+			{
+				gtk_tree_selection_unselect_all (selection);
+				gtk_tree_selection_select_path (selection, path);
+				gtk_tree_path_free (path);
+			}
+		}
+
 		gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL,
 				event->button, event->time);
 	} else {
@@ -2035,7 +2052,7 @@ set_busy (GeditFileBrowserWidget *obj, gboolean busy)
 	GdkCursor *cursor;
 	GdkWindow *window;
 	
-	window = GTK_WIDGET (obj->priv->treeview)->window;
+	window = gtk_widget_get_window (GTK_WIDGET (obj->priv->treeview));
 	
 	if (!GDK_IS_WINDOW (window))
 		return;
